@@ -43,11 +43,12 @@ OC.L10N.register(
     "Starred" : "Označeno zvjezdicom",
     "Explore" : "Istraži",
     "Settings" : "Postavke",
+    "Documentation" : "Dokumentacija",
     "Keyboard shortcuts" : "Tipkovni prečaci",
     "Disable mark read through scrolling" : "Onemogući označavanje kao pročitano pri pomicanju",
-    "Compact view" : "Kompaktni prikaz",
     "Show all articles" : "Prikaži sve članke",
     "Reverse ordering (oldest on top)" : "Obrnuti poredak (prvo najstariji)",
+    "Default" : "Zadani",
     "Rename" : "Preimenuj",
     "Delete" : "Izbriši",
     "Rename Feed" : "Preimenuj sažetak",
@@ -60,6 +61,8 @@ OC.L10N.register(
     "Disable full text" : "Onemogući cijeli tekst",
     "Unread updated" : "Ažurirano nepročitano",
     "Ignore updated" : "Zanemari ažurirano",
+    "Previous" : "Natrag",
+    "Next" : "Dalje",
     "Toggle star article" : "Postavi/ukloni zvjezdicu s članka",
     "Mark unread" : "Označi kao nepročitano",
     "Close details" : "Zatvori pojedinosti",
@@ -73,12 +76,13 @@ OC.L10N.register(
     "Keep article unread" : "Drži članak kao nepročitan",
     "Toggle keep current article unread" : "Prebaci i zadržati trenutni članak nepročitanim",
     "Remove keep article unread" : "Makni održavanje članaka nepročitanim",
+    "Title" : "Naslov",
     "Keyboard shortcut" : "Tipkovni prečac",
     "Action" : "Radnja",
-    "right" : "desno",
     "Jump to next article" : "Prijeđi na sljedeći članak",
-    "left" : "lijevo",
     "Jump to previous article" : "Prijeđi na prethodni članak",
+    "right" : "desno",
+    "left" : "lijevo",
     "Star article and jump to next one" : "Označi zvjezdicom članak i prijeđi na sljedeći",
     "Open article in new tab" : "Otvori članak u novoj kartici",
     "Refresh" : "Osvježi",
@@ -118,6 +122,7 @@ OC.L10N.register(
     "Collapse" : "Sakrij",
     "Deleted folder" : "Izbrisana mapa",
     "Undo delete folder" : "Vrati izbrisanu mapu",
+    "Compact view" : "Kompaktni prikaz",
     "Expand articles on key navigation" : "Proširi članke pri ključnoj navigaciji",
     "Subscriptions (OPML)" : "Pretplate (OPML)",
     "Import" : "Uvezi",
@@ -127,7 +132,6 @@ OC.L10N.register(
     "Unread/Starred Articles" : "Nepročitani/članci označeni zvjezdicom",
     "Error when importing: file does not contain valid JSON" : "Pogreška pri uvozu: datoteka ne sadrži valjani JSON",
     "Help" : "Pomoć",
-    "Documentation" : "Dokumentacija",
     "Report a bug" : "Prijavi pogrešku"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
