@@ -41,11 +41,14 @@ OC.L10N.register(
     "Starred" : "Stjörnumerkt",
     "Explore" : "Skoða",
     "Settings" : "Stillingar",
+    "Documentation" : "Hjálparskjöl",
     "Keyboard shortcuts" : "Flýtilyklar",
     "Disable mark read through scrolling" : "Gera óvirkt að merkja sem lesið við skrun",
-    "Compact view" : "Þjöppuð sýn",
     "Show all articles" : "Birta allar greinar",
     "Reverse ordering (oldest on top)" : "Öfug röðun (elsta efst)",
+    "Default" : "Sjálfgefið",
+    "Vertical" : "Lóðrétt",
+    "Horizontal" : "Lárétt",
     "Rename" : "Endurnefna",
     "Delete" : "Eyða",
     "Rename Feed" : "Endurnefna streymi",
@@ -58,6 +61,8 @@ OC.L10N.register(
     "Disable full text" : "Afvirkja allan texta",
     "Unread updated" : "Ólesið uppfært",
     "Ignore updated" : "Hunsa uppfært",
+    "Previous" : "Fyrra",
+    "Next" : "Næst",
     "Toggle star article" : "Víxla stjörnumerkingu af/á grein",
     "Mark unread" : "Merkja sem ólesið",
     "Close details" : "Loka nánari upplýsingum",
@@ -70,12 +75,15 @@ OC.L10N.register(
     "Keep article unread" : "Halda greininni sem ólesinni",
     "Toggle keep current article unread" : "Víxla af/á að halda greininni sem ólesinni",
     "Remove keep article unread" : "Fjarlægja að halda greininni sem ólesinni",
+    "{num} seconds" : "{num} sekúndur ",
+    "{num} minutes ago" : "fyrir {num} mínútum síðan",
+    "{num} hours ago" : "fyrir {num} klukkustundum síðan",
     "Keyboard shortcut" : "Flýtilykill",
     "Action" : "Aðgerð",
-    "right" : "hægri",
     "Jump to next article" : "Hoppa á næstu grein",
-    "left" : "vinstri",
     "Jump to previous article" : "Hoppa á fyrri grein",
+    "right" : "hægri",
+    "left" : "vinstri",
     "Star article and jump to next one" : "Stjörnumerkja grein og hoppa í næstu",
     "Open article in new tab" : "Opna grein í nýjum flipa",
     "Refresh" : "Endurlesa",
@@ -93,6 +101,7 @@ OC.L10N.register(
     "No unread articles available" : "Engar ólesnar greinar tiltækar",
     "Star article" : "Stjörnumerkja grein",
     "Unstar article" : "Taka stjörnugjöf af grein",
+    "Share on social media" : "Deila á samfélagsmiðlum",
     "Description" : "Lýsing",
     "Toggle expand article in compact view" : "Víxla útflettingu greinar af/á í þjappaðri sýn",
     "Mark current article's feed/folder read" : "Merkja streymi/möppu núverandi greinar sem lesið",
@@ -109,6 +118,7 @@ OC.L10N.register(
     "Collapse" : "Fella saman",
     "Deleted folder" : "Eydd mappa",
     "Undo delete folder" : "Afturkalla eyðingu á möppu",
+    "Compact view" : "Þjöppuð sýn",
     "Expand articles on key navigation" : "Virkja útflettingu greina við flakk með lyklaborði",
     "Subscriptions (OPML)" : "Áskriftir (OPML)",
     "Import" : "Flytja inn",
@@ -118,7 +128,6 @@ OC.L10N.register(
     "Unread/Starred Articles" : "Ólesnar/stjörnumerktar greinar",
     "Error when importing: file does not contain valid JSON" : "Villa við innflutning: skrá inniheldur ekki gilt JSON",
     "Help" : "Hjálp",
-    "Documentation" : "Hjálparskjöl",
     "Report a bug" : "Tilkynna um villu"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
