@@ -52,11 +52,14 @@ OC.L10N.register(
     "Starred" : "별표",
     "Explore" : "탐색",
     "Settings" : "설정",
+    "Documentation" : "문서",
     "Keyboard shortcuts" : "키보드 단축키",
     "Disable mark read through scrolling" : "스크롤 시 읽은 상태로 표시 비활성화",
-    "Compact view" : "축소된 보기",
     "Show all articles" : "모든 글 보기",
     "Reverse ordering (oldest on top)" : "순서 뒤집기(오래된 항목 먼저)",
+    "Default" : "디폴트",
+    "Vertical" : "세로",
+    "Horizontal" : "가로",
     "Rename Folder" : "폴더 이름 바꾸기",
     "Are you sure you want to delete?" : "삭제하시겠습니까?",
     "Rename" : "이름 바꾸기",
@@ -71,6 +74,8 @@ OC.L10N.register(
     "Disable full text" : "전문 사용 안 함",
     "Unread updated" : "업데이트된 항목 읽지 않음으로 표시",
     "Ignore updated" : "업데이트된 항목 무시",
+    "Previous" : "이전",
+    "Next" : "다음",
     "Share within Instance" : "인스턴스 내에서 공유",
     "Toggle star article" : "글 별표 전환",
     "Mark unread" : "읽지 않음 상태로 표시",
@@ -91,12 +96,13 @@ OC.L10N.register(
     "{num} days ago" : "{num}일 전",
     "{num} months ago" : "{num}개월 전",
     "{num} years ago" : "{num}년 전",
+    "Title" : "제목",
     "Keyboard shortcut" : "키보드 단축키",
     "Action" : "동작",
-    "right" : "오른쪽",
     "Jump to next article" : "다음 글로 이동",
-    "left" : "왼쪽",
     "Jump to previous article" : "이전 글로 이동",
+    "right" : "오른쪽",
+    "left" : "왼쪽",
     "Star article and jump to next one" : "글에 별표를 붙이고 다음 항목으로 이동",
     "Open article in new tab" : "새 탭으로 글 열기",
     "Refresh" : "새로 고침",
@@ -139,6 +145,7 @@ OC.L10N.register(
     "Collapse" : "접기",
     "Deleted folder" : "삭제된 폴더",
     "Undo delete folder" : "폴더 삭제 실행 취소",
+    "Compact view" : "축소된 보기",
     "Expand articles on key navigation" : "키 탐색 시 글 확장",
     "Subscriptions (OPML)" : "구독(OPML)",
     "Import" : "가져오기",
@@ -148,7 +155,6 @@ OC.L10N.register(
     "Unread/Starred Articles" : "읽지 않은/별표한 글",
     "Error when importing: file does not contain valid JSON" : "가져오기 오류: 파일이 올바른 JSON을 포함하지 않음",
     "Help" : "도움말",
-    "Documentation" : "문서",
     "Report a bug" : "버그 보고"
 },
 "nplurals=1; plural=0;");
