@@ -20,6 +20,7 @@ OC.L10N.register(
     "Folder name" : "Aplanko pavadinimas",
     "Username" : "Naudotojo vardas",
     "Password" : "Slaptažodis",
+    "Unknown error!" : "Nežinoma klaida!",
     "Feed exists already!" : "Kanalas jau yra!",
     "New folder" : "Naujas aplankas",
     "Folder exists already!" : "Aplankas jau yra!",
@@ -50,6 +51,7 @@ OC.L10N.register(
     "Starred" : "Pažymėti žvaigždute",
     "Explore" : "Išvalgyti",
     "Settings" : "Nustatymai",
+    "Documentation" : "Dokumentacija",
     "Keyboard shortcuts" : "Klavišų kombinacijos",
     "Show all articles" : "Rodyti visus straipsnius",
     "Reverse ordering (oldest on top)" : "Atvirkštinis rikiavimas (seniausi viršuje)",
@@ -71,6 +73,10 @@ OC.L10N.register(
     "Disable full text" : "Išjungti raiškųjį tekstą",
     "Unread updated" : "Žymėti atnaujintus straipsnius kaip neskaitytus",
     "Ignore updated" : "Nepaisyti atnaujintų straipsnių",
+    "Previous Item" : "Ankstesnis elementas",
+    "Previous" : "Ankstesnis",
+    "Next Item" : "Kitas elementas",
+    "Next" : "Kitas",
     "Toggle star article" : "Perjungti straipsnio žymėjimą žvaigždute",
     "Mark unread" : "Žymėti kaip neskaitytą",
     "Close details" : "Užverti išsamesnę informaciją",
@@ -90,6 +96,7 @@ OC.L10N.register(
     "{num} months ago" : "prieš {num} mėn.",
     "{num} years ago" : "prieš {num} m.",
     "Last update" : "Paskutinis atnaujinimas",
+    "Next update" : "Kitas atnaujinimas",
     "Title" : "Pavadinimas",
     "Keyboard shortcut" : "Spartusis klavišas",
     "Action" : "Veiksmas",
@@ -147,7 +154,6 @@ OC.L10N.register(
     "Unread/Starred Articles" : "Neskaityti/Pažymėti žvaigždute straipsniai",
     "Error when importing: file does not contain valid JSON" : "Klaida importuojant: faile nėra teisingo JSON",
     "Help" : "Pagalba",
-    "Documentation" : "Dokumentacija",
     "Report a bug" : "Pranešti apie klaidą"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
