@@ -2,7 +2,7 @@ OC.L10N.register(
     "news",
     {
     "Request failed, network connection unavailable!" : "Pedido falhou, ligação à rede indisponível!",
-    "Request unauthorized. Are you logged in?" : "Pedido não autorizado. Fez o login?",
+    "Request unauthorized. Are you logged in?" : "Pedido não autorizado. Fez o início de sessão?",
     "Token expired or app not enabled! Reload the page!" : "Token expirou ou aplicação não ativa! Recarregue a página!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Erro interno do servidor. Veja por favor o ficheiro na pasta data/nextcloud.log para mais informações!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Falha no pedido, Nextcloud está atualmente em modo de manutenção!",
@@ -29,7 +29,7 @@ OC.L10N.register(
     "Maximum redirects" : "Máximo de redirecionamentos",
     "Feed fetcher timeout" : "A obtenção do feed expirou",
     "Explore Service URL" : "Explorar Serviço URL",
-    "Update interval" : "Intervalo de actualização",
+    "Update interval" : "Intervalo de atualização",
     "Use system cron for updates" : "Use o programador do sistema para as atualizações",
     "Disable this if you use a custom updater." : "Desative isto se é um sistema de atualizações feito à medida.",
     "Move" : "Mover",
@@ -40,16 +40,21 @@ OC.L10N.register(
     "Starred" : "Marcado",
     "Explore" : "Explorar",
     "Settings" : "Definições",
+    "Documentation" : "Documentação",
     "Keyboard shortcuts" : "Atalhos de teclado",
+    "Article feed information" : "Informação da \"feed\" do artigo",
     "Disable mark read through scrolling" : "Desativar marcar ler através de movimento",
-    "Compact view" : "Visualização Compacta",
     "Show all articles" : "Mostrar todos os artigos",
     "Reverse ordering (oldest on top)" : "Ordem inversa (antigos no topo)",
+    "Default" : "Predefinido",
     "Rename" : "Renomear",
     "Delete" : "Apagar",
-    "Rename Feed" : "Renomear <em>Feed</em>",
+    "Open Feed URL" : "Abrir URL da Feed",
+    "Rename Feed" : "Renomear Feed",
     "Newest first" : "Recentes primeiro",
     "Oldest first" : "Antigos primeiro",
+    "Previous" : "Anterior",
+    "Next" : "Seguinte",
     "Toggle star article" : "Alternar estrela do artigo",
     "Mark unread" : "Marcar como não lido",
     "by" : "por",
@@ -62,11 +67,15 @@ OC.L10N.register(
     "Keep article unread" : "Marcar artigo como não lido",
     "Toggle keep current article unread" : "Alternar manter o artigo atual como não lido",
     "Remove keep article unread" : "Remover marcação de artigo não lido",
+    "Last update" : "Último refrescamento",
+    "Time when the feed was last downloaded" : "A hora em que a \"feed\" foi transferida pela última vez",
+    "Title" : "Título",
+    "Not available" : "Não disponível",
     "Keyboard shortcut" : "Atalho de teclado",
-    "right" : "direita",
     "Jump to next article" : "Ir para o artigo seguinte",
-    "left" : "esquerda",
     "Jump to previous article" : "Ir para o artigo anterior",
+    "right" : "direita",
+    "left" : "esquerda",
     "Star article and jump to next one" : "Destacar artigo e saltar para o próximo",
     "Open article in new tab" : "Abrir artigo num separador novo",
     "Refresh" : "Atualizar",
@@ -77,27 +86,29 @@ OC.L10N.register(
     "Scroll to active navigation entry" : "Vá até a entrada de navegação ativa",
     "Shift" : "Shift",
     "How to set up the operating system cron" : "Como configurar o cron no sistema operativo",
-    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale e configure um actualizador paralelo mais rápido que use a API de actualizações da aplicação Notícias",
+    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale e configure um atualizador paralelo mais rápido que use a API de atualizações da aplicação Notícias",
     "No articles available" : "Não há artigos disponíveis",
     "No unread articles available" : "Não há artigos por ler disponíveis",
     "Star article" : "Destacar artigo",
     "Unstar article" : "Retirar destaque",
     "No users found" : "Não foram encontrados utilizadores",
     "Description" : "Descrição",
-    "Toggle expand article in compact view" : "Alternar expandir artigo na visulaização compacta",
-    "Mark current article's feed/folder read" : "Marcar a pasta/feed do artigo atual como lida",
+    "Toggle expand article in compact view" : "Alternar expandir artigo na visualização compacta",
+    "Mark current article's feed/folder read" : "Marcar a pasta/\"feed\" do artigo atual como lida",
     "Folder" : "Pasta",
     "Go back" : "Voltar",
     "New Folder" : "Nova Pasta",
     "Create" : "Criar",
     "Update failed more than 50 times" : "A atualização falhou mais de 50 vezes",
-    "Deleted feed" : "Apagar feed",
-    "Undo delete feed" : "Desfazer apagar a feed",
+    "Deleted feed" : "Feed eliminada",
+    "Undo delete feed" : "Anular eliminar feed",
     "Menu" : "Menu",
+    "Open feed URL" : "Abrir URL da feed",
     "Dismiss" : "Rejeitar",
     "Collapse" : "Expandir",
     "Deleted folder" : "Apagar pasta",
     "Undo delete folder" : "Anular apagar pasta",
+    "Compact view" : "Visualização compacta",
     "Expand articles on key navigation" : "Expandir artigos ao navegar por tecla",
     "Subscriptions (OPML)" : "Subscrições (OPML)",
     "Import" : "Importar",
@@ -106,7 +117,6 @@ OC.L10N.register(
     "Unread/Starred Articles" : "Artigos Não Lidos/Classificados",
     "Error when importing: file does not contain valid JSON" : "Ocorreu um erro na importação: o ficheiro não contém JSON válido",
     "Help" : "Ajuda",
-    "Documentation" : "Documentação",
     "Report a bug" : "Reportar um erro"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
