@@ -45,11 +45,12 @@ OC.L10N.register(
     "Starred" : "Preferidos",
     "Explore" : "Esplorare",
     "Settings" : "Cunfiguratzione",
+    "Documentation" : "Documentatzione",
     "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
     "Disable mark read through scrolling" : "Disativa su de marcare comente non lèghidu in s'iscurrimentu",
-    "Compact view" : "Bista istrinta",
     "Show all articles" : "Mustra is artìculos",
     "Reverse ordering (oldest on top)" : "Òrdine invertidu (su prus betzu in artu)",
+    "Default" : "Predefinidu",
     "Rename" : "Torra a numenare",
     "Delete" : "Cantzella",
     "Rename Feed" : "Torra a numenare Fonte",
@@ -62,6 +63,8 @@ OC.L10N.register(
     "Disable full text" : "Disativa totu su testu",
     "Unread updated" : "Non lèghidos agiornados",
     "Ignore updated" : "Ignora agiornados",
+    "Previous" : "Pretzedente",
+    "Next" : "Imbeniente",
     "Toggle star article" : "Còmmuta s'agiunta a is preferidos de un'artìculu",
     "Mark unread" : "Marca comente no lèghidu",
     "by" : "dae",
@@ -80,12 +83,13 @@ OC.L10N.register(
     "{num} days ago" : "{num} dies a oe",
     "{num} months ago" : "{num} meses a oe",
     "{num} years ago" : "{num} annos a oe",
+    "Title" : "Tìtulu",
     "Keyboard shortcut" : "Curtziadòrgiu de tecladu",
     "Action" : "Atzione",
-    "right" : "dereta",
     "Jump to next article" : "Brinca a s'artìculu imbeniente",
-    "left" : "manca",
     "Jump to previous article" : "Brinca a s'artìculu de in antis",
+    "right" : "dereta",
+    "left" : "manca",
     "Star article and jump to next one" : "Agiùnghe s'artìculu a is preferidos e brinca a s'imbeniente",
     "Open article in new tab" : "Aberi artìculu in un'ischeda noa",
     "Refresh" : "Agiorna",
@@ -125,6 +129,7 @@ OC.L10N.register(
     "Collapse" : "Cuntrae",
     "Deleted folder" : "Elìmina sa cartella",
     "Undo delete folder" : "Annulla s'eliminatzione de sa cartella",
+    "Compact view" : "Bista istrinta",
     "Expand articles on key navigation" : "Ammania·nche is artìculos navighende cun is butones",
     "Subscriptions (OPML)" : "Sutaiscritziones (OPML)",
     "Import" : "Importa",
@@ -134,7 +139,6 @@ OC.L10N.register(
     "Unread/Starred Articles" : "Artìculos non lèghidos/preferidos",
     "Error when importing: file does not contain valid JSON" : "Errore importende: s'archìviu non cuntenet unu JSON bàlidu",
     "Help" : "Agiudu",
-    "Documentation" : "Documentatzione",
     "Report a bug" : "Report a bug"
 },
 "nplurals=2; plural=(n != 1);");
