@@ -41,11 +41,13 @@ OC.L10N.register(
     "Starred" : "Із зірочкою",
     "Explore" : "Дослідити",
     "Settings" : "Налаштування",
+    "Documentation" : "Документація",
     "Keyboard shortcuts" : "Сполучення клавіш",
     "Disable mark read through scrolling" : "Вимкнути читання поміток при прокрутці",
-    "Compact view" : "Компактний вигляд",
     "Show all articles" : "Показати всі статті",
     "Reverse ordering (oldest on top)" : "Зворотний порядок (найстаріші зверху)",
+    "Vertical" : "Вертикальний",
+    "Horizontal" : "Горизонтальний",
     "Rename Folder" : "Перейменувати каталог",
     "Are you sure you want to delete?" : "Ви впевнені, що хочете видалити?",
     "Rename" : "Перейменувати",
@@ -57,6 +59,8 @@ OC.L10N.register(
     "Oldest first" : "Старіші спочатку",
     "Enable full text" : "Увімкнути контекстний",
     "Disable full text" : "Вимкнути контекстний",
+    "Previous" : "Назад",
+    "Next" : "Далі",
     "Toggle star article" : "Позначити статтю",
     "Mark unread" : "Позначити як не прочитане",
     "by" : "по",
@@ -74,12 +78,14 @@ OC.L10N.register(
     "{num} days ago" : "{num} днів тому",
     "{num} months ago" : "{num} місяців тому",
     "{num} years ago" : "{num} років тому",
+    "Title" : "Заголовок",
+    "Not available" : "Не доступно",
     "Keyboard shortcut" : "Сполучення клавіш",
     "Action" : "Дія ",
-    "right" : "праворуч",
     "Jump to next article" : "Наступна стаття",
-    "left" : "ліворуч",
     "Jump to previous article" : "Попередня стаття",
+    "right" : "праворуч",
+    "left" : "ліворуч",
     "Star article and jump to next one" : "Позначити статтю та перейти до наступної",
     "Open article in new tab" : "Відкрити статтю в новій вкладці",
     "Refresh" : "Оновити",
@@ -111,6 +117,7 @@ OC.L10N.register(
     "Collapse" : "Згорнути",
     "Deleted folder" : "Вилучений каталог",
     "Undo delete folder" : "Скасувати вилучення каталогу",
+    "Compact view" : "Компактний вигляд",
     "Expand articles on key navigation" : "Розширенні артикули під час навігації по ключах",
     "Subscriptions (OPML)" : "Підписки (OPML)",
     "Import" : "Імпорт",
@@ -119,7 +126,6 @@ OC.L10N.register(
     "Unread/Starred Articles" : "Непрочитані/Вибрані статті",
     "Error when importing: file does not contain valid JSON" : "Помилка при імпорті: файл не містить дійсний JSON",
     "Help" : "Допомога",
-    "Documentation" : "Документація",
     "Report a bug" : "Повідомити про помилку"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
